==> zio-aws-route53recoverycontrolconfig_2.12-5.17.126.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/ListRoutingControlsResponse.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__stringMin1Max8096PatternS
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListRoutingControlsResponse(
    nextToken: Option[__stringMin1Max8096PatternS] = None,
    routingControls: Option[
      Iterable[zio.aws.route53recoverycontrolconfig.model.RoutingControl]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse = {
    import ListRoutingControlsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse
      .builder()
      .optionallyWith(
        nextToken.map(value =>
          __stringMin1Max8096PatternS.unwrap(value): java.lang.String
        )
      )(_.nextToken)
      .optionallyWith(
        routingControls.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.routingControls)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse
      .wrap(buildAwsValue())
}
object ListRoutingControlsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse =
      zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse(
        nextToken.map(value => value),
        routingControls.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Option[__stringMin1Max8096PatternS]
    def routingControls: Option[
      List[zio.aws.route53recoverycontrolconfig.model.RoutingControl.ReadOnly]
    ]
    def getNextToken: ZIO[Any, AwsError, __stringMin1Max8096PatternS] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getRoutingControls: ZIO[Any, AwsError, List[
      zio.aws.route53recoverycontrolconfig.model.RoutingControl.ReadOnly
    ]] = AwsError.unwrapOptionField("routingControls", routingControls)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse
  ) extends zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse.ReadOnly {
    override val nextToken: Option[__stringMin1Max8096PatternS] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.route53recoverycontrolconfig.model.primitives
          .__stringMin1Max8096PatternS(value)
      )
    override val routingControls: Option[
      List[zio.aws.route53recoverycontrolconfig.model.RoutingControl.ReadOnly]
    ] = scala
      .Option(impl.routingControls())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.route53recoverycontrolconfig.model.RoutingControl.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse
  ): zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.13-5.17.146.2-sources.jar: zio/aws/route53recoverycontrolconfig/model/ListRoutingControlsResponse.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__stringMin1Max8096PatternS
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListRoutingControlsResponse(
    nextToken: Option[__stringMin1Max8096PatternS] = None,
    routingControls: Option[
      Iterable[zio.aws.route53recoverycontrolconfig.model.RoutingControl]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse = {
    import ListRoutingControlsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        routingControls.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.routingControls)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse
      .wrap(buildAwsValue())
}
object ListRoutingControlsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse =
      zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse(
        nextToken.map(value => value),
        routingControls.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Option[__stringMin1Max8096PatternS]
    def routingControls: Option[
      List[zio.aws.route53recoverycontrolconfig.model.RoutingControl.ReadOnly]
    ]
    def getNextToken: ZIO[Any, AwsError, __stringMin1Max8096PatternS] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getRoutingControls: ZIO[Any, AwsError, List[
      zio.aws.route53recoverycontrolconfig.model.RoutingControl.ReadOnly
    ]] = AwsError.unwrapOptionField("routingControls", routingControls)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse
  ) extends zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse.ReadOnly {
    override val nextToken: Option[__stringMin1Max8096PatternS] = scala
      .Option(impl.nextToken())
      .map(value => value: __stringMin1Max8096PatternS)
    override val routingControls: Option[
      List[zio.aws.route53recoverycontrolconfig.model.RoutingControl.ReadOnly]
    ] = scala
      .Option(impl.routingControls())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.route53recoverycontrolconfig.model.RoutingControl.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListRoutingControlsResponse
  ): zio.aws.route53recoverycontrolconfig.model.ListRoutingControlsResponse.ReadOnly =
    new Wrapper(impl)
}
